package com.ibm.jsf.gui;

import java.util.List;

import com.ibm.jsf.model.CustomerService;
import com.ibm.jsf.model.IService;
import com.ibm.jsf.model.OrderService;

/**
 * A single instance is linked to every user session
 */
public class UserSession {

    public static final String CUSTOMER = "customer";

    public static final String ORDER = "order";

    public static final String UNSPECIFIED = "unspecified";

    private String currentServiceType = UNSPECIFIED;

    public void initService(String type) {
        if (CUSTOMER.equals(type) && !currentServiceType.equals(CUSTOMER)) {
            System.err.println("UserSession : CustomerService init");
            currentService = new CustomerService();
            currentServiceType = CUSTOMER;
        }
        if (ORDER.equals(type) && !currentServiceType.equals(ORDER)) {
            System.err.println("UserSession : OrderService init");
            currentService = new OrderService();
            currentServiceType = ORDER;
        }
    }

    public UserSession() {
    }

    /**
     * This architecture manages a singleton service.
     */
    private IService currentService;

    // CUSTOMERSERVICE
    public CustomerService getCustomerService() {
        return (CustomerService) currentService;
    }

    public void setCustomerService(CustomerService customerService) {
        this.currentService = customerService;
    }

    // ORDERSERVICE
    public OrderService getOrderService() {
        return (OrderService) currentService;
    }

    public void setOrderService(OrderService orderService) {
        this.currentService = orderService;
    }

    private IService getCurrentService() {
        return currentService;
    }

    public Object load(String id) {
        return getCurrentService().load(id);
    }

    public List loadList() {
        return getCurrentService().loadList();
    }

    public void save(Object instance) {
        getCurrentService().save(instance);
    }

    public void create(Object instance) {
        getCurrentService().create(instance);
    }

    public void delete(Object instance) {
        getCurrentService().delete(instance);
    }

 
}
